# builddsl

A superset of the Python programming language with support for closures and multi-line lambdas.

BuildDSL is an "almost superset" of Python 3; adding a lot of syntactical features that make it more
convenient to describe build configurations at the cost of some other syntax features of the native Python
language (like set literals).

## Installation

    $ pip install builddsl

The `builddsl` package requires at least Python 3.8.

## Projects using BuildDSL

* [Novella](https://niklasrosenstein.github.io/novella/)
